package com.csc.library.controller;

import com.csc.library.command.CscCommand;
import com.csc.library.factory.CommandFactory;
import com.csc.library.factory.PropertiesFactory;
import com.csc.library.factory.RequestFactory;
import com.csc.library.factory.ResponseFactory;
import com.csc.library.factory.ThreadsPoolsFactory;
import com.csc.library.properties.CscSession;
import com.csc.library.request.RequestWebsocket;
import com.csc.library.response.ResponseStatus;
import com.csc.library.task.CommandTask;
import com.csc.library.task.TaskCommand;
import com.csc.library.utilities.MyLog;

public class WebSocketCommandController {
	private static WebSocketCommandController instance;
	//private Map<CscSession , Map<String , RequestWebsocket>> currentCommand = new HashMap<CscSession , Map<String , RequestWebsocket>>();
	private ResponseFactory responseFact;
	private PropertiesFactory propFact;
	private CommandFactory commandFact;
	private ThreadsPoolsFactory threadsFact;
	private RequestFactory reqFact;
	
	private WebSocketCommandController(){
	}
	
	public static WebSocketCommandController getInstance(){
		try{
			if(instance == null){
				instance = new WebSocketCommandController();
				instance.responseFact = ResponseFactory.getInstance();
				instance.reqFact = RequestFactory.getInstance();
				instance.commandFact = CommandFactory.getInstance();
				instance.threadsFact = ThreadsPoolsFactory.getInstance();
			}
		}catch(Exception e){
			e.printStackTrace();
		}
		return instance;
	}
	
	public void executeCommand(CscSession session, String json){
		try{
			RequestWebsocket req = reqFact.createRequestWebSocket(json);
			executeCommand(session, req);
		}catch(Exception e){
			MyLog.error(this , session.getUProfile() , e);
		}
	}
	
	public void executeCommand(final CscSession session, final RequestWebsocket req){
		responseFact.sendResponseWebsocket(session, req,
				ResponseStatus.Receive,
				ResponseStatus.Receive.getDescription());
		
		final CscCommand command = commandFact.getCommand(session , req);
		CommandTask task = new TaskCommand(session , req , command); 
		threadsFact.execute(task);
	}
}
